==> 0.4.2&file=in_ffsox-2a-0.4.2-src.tar.gz: in_ffsox-2a-0.4.2/in_ffsox/about.c <==
/*
 * about.c
 * Copyright (C) 2010 Peter Belkner <pbelkner@snafu.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
// http://www.gnu.org/licenses/gpl-howto.html
#include "resource.h"
#include "plugin.h"
#include "ffsox.h"
#include <commctrl.h>

#define URL_PFX "file:///"
#define setdlgitemurl_stub_valid (NULL!=*SetDlgItemUrl)

static void set_link(HWND hDlg, int id, char *buf, int size)
{
  if (setdlgitemurl_stub_valid) {
    GetDlgItemTextA(hDlg,id,buf,size);
    SetDlgItemUrl(hDlg,id,buf);
  }
}

BOOL CALLBACK AboutDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam)
{
  static char buf[(sizeof URL_PFX)+MAX_PATH];

  switch (message) {
    case WM_INITDIALOG:
	  SetWindowTextA(hDlg,"About " CAPTION);
      SetDlgItemTextA(hDlg, IDC_STATIC_ABOUT_VERSION,
          CAPTION ", Copyright  2010-2013 Peter Bekner.");

#if 0 // {
      if (setdlgitemurl_stub_valid) {
        const char *rp;
        char *wp=buf;

        for (rp=URL_PFX;0!=*rp;++rp)
          *wp++=*rp;

        for (rp=ini.path;rp<ini.p;++rp) {
          switch (*rp) {
            case '\\':
              *wp++='/';
              break;
            case ' ':
              *wp++='%';
              *wp++='2';
              *wp++='0';
              break;
            default:
              *wp++=*rp;
              break;
          }
        }

        for (rp="in_ffsox/doc/index.html";0!=*rp;++rp)
          *wp++=*rp;

        *wp=0;
        __SetDlgItemUrl(hDlg,IDC_STATIC_ABOUT_DOC,buf);
        SetDlgItemText(hDlg,IDC_STATIC_ABOUT_DOC,"documentation");
      }
#endif // }

      set_link(hDlg, IDC_STATIC_ABOUT_GPL_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_SDK_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_FFMPEG_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_SOX_URL, buf, sizeof buf);
#if 0 // {
      set_link(hDlg, IDC_STATIC_ABOUT_LIBA52_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_LIBMAD_URL, buf, sizeof buf);
#endif // }
      set_link(hDlg, IDC_STATIC_ABOUT_FLAC_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_OGG_VORBIS_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_WAVPACK_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_SET_URL_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_MINGW_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_MSVSEE_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_RESEDIT_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_AUTOBUILDS_URL, buf, sizeof buf);
      break;
    case WM_COMMAND:
      switch (LOWORD(wParam)) {
        case IDOK:
          EndDialog(hDlg, 1);
          return TRUE;
        case IDCANCEL:
          EndDialog(hDlg, 0);
          return TRUE;
      }

      break;
  }

  return FALSE;
}

==> 0.6.0&file=in_ffsox-2a-0.6.0-src.tar.gz: in_ffsox-2a-0.6.0/in_ffsox/about.c <==
/*
 * about.c
 * Copyright (C) 2010 Peter Belkner <pbelkner@snafu.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
// http://www.gnu.org/licenses/gpl-howto.html
#include "resource/resource.h"
#include "plugin.h"
#include "ffsox.h"
#include <commctrl.h>
#include <dlgitemurl.h>

#define URL_PFX "file:///"
#define setdlgitemurl_stub_valid (NULL!=*SetDlgItemUrl)

static void set_link(HWND hDlg, int id, char *buf, int size)
{
  if (setdlgitemurl_stub_valid) {
    GetDlgItemTextA(hDlg,id,buf,size);
    SetDlgItemUrl(hDlg,id,buf);
  }
}

BOOL CALLBACK AboutDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam)
{
  static char buf[(sizeof URL_PFX)+MAX_PATH];

  switch (message) {
    case WM_INITDIALOG:
	  SetWindowTextA(hDlg,"About " CAPTION);
      SetDlgItemTextA(hDlg, IDC_STATIC_ABOUT_VERSION,
          CAPTION ", Copyright  2010-2013 Peter Bekner.");

#if 0 // {
      if (setdlgitemurl_stub_valid) {
        const char *rp;
        char *wp=buf;

        for (rp=URL_PFX;0!=*rp;++rp)
          *wp++=*rp;

        for (rp=ini.path;rp<ini.p;++rp) {
          switch (*rp) {
            case '\\':
              *wp++='/';
              break;
            case ' ':
              *wp++='%';
              *wp++='2';
              *wp++='0';
              break;
            default:
              *wp++=*rp;
              break;
          }
        }

        for (rp="in_ffsox/doc/index.html";0!=*rp;++rp)
          *wp++=*rp;

        *wp=0;
        __SetDlgItemUrl(hDlg,IDC_STATIC_ABOUT_DOC,buf);
        SetDlgItemText(hDlg,IDC_STATIC_ABOUT_DOC,"documentation");
      }
#endif // }

      set_link(hDlg, IDC_STATIC_ABOUT_GPL_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_SDK_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_FFMPEG_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_SOX_URL, buf, sizeof buf);
#if 0 // {
      set_link(hDlg, IDC_STATIC_ABOUT_LIBA52_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_LIBMAD_URL, buf, sizeof buf);
#endif // }
      set_link(hDlg, IDC_STATIC_ABOUT_FLAC_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_OGG_VORBIS_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_WAVPACK_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_SET_URL_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_MINGW_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_MSVSEE_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_RESEDIT_URL, buf, sizeof buf);
      set_link(hDlg, IDC_STATIC_ABOUT_AUTOBUILDS_URL, buf, sizeof buf);
      break;
    case WM_COMMAND:
      switch (LOWORD(wParam)) {
        case IDOK:
          EndDialog(hDlg, 1);
          return TRUE;
        case IDCANCEL:
          EndDialog(hDlg, 0);
          return TRUE;
      }

      break;
  }

  return FALSE;
}
